@@ -19,6 +19,11 @@ Usage:
     qsv exclude [options] <columns1> <input1> <columns2> <input2>
     qsv exclude --help
 
+input arguments:
+    <input1> is the file from which data will be removed.
+    <input2> is the file containing the data to be removed from <input1> 
+     e.g. 'qsv exclude id records.csv id previously-processed.csv'
+
 exclude options:
     -i, --ignore-case      When set, matching is done case insensitively.
     -v                     When set, matching rows will be the only ones included,
@@ -39,6 +44,7 @@ use std::{collections::hash_map::Entry, fmt, fs, io, str};
 use ahash::AHashMap;
 use byteorder::{BigEndian, WriteBytesExt};
 use serde::Deserialize;
+use simdutf8::basic::from_utf8;
 
 use crate::{
     config::{Config, Delimiter},
@@ -247,7 +253,7 @@ fn get_row_key(sel: &Selection, row: &csv::ByteRecord, casei: bool) -> Vec<ByteS
 
 #[inline]
 fn transform(bs: &[u8], casei: bool) -> ByteString {
-    let s = unsafe { str::from_utf8_unchecked(bs) };
+    let s = from_utf8(bs).unwrap_or_default();
     if casei {
         let norm: String = s
             .trim()
