@@ -53,6 +53,8 @@ Common options:
                                appear as the header row in the output.
     -d, --delimiter <arg>      The field delimiter for reading CSV data.
                                Must be a single character. [default: ,]
+    --no-memcheck              Do not check if there is enough memory to load the
+                               entire CSV into memory.
 "#;
 
 use std::{collections::HashSet, fs::File, io::Write, path::Path};
@@ -85,6 +87,7 @@ pub struct Args {
     pub flag_no_headers:      bool,
     pub flag_delimiter:       Option<Delimiter>,
     pub arg_input:            Option<String>,
+    pub flag_no_memcheck:     bool,
 }
 
 const STDIN_CSV: &str = "stdin.csv";
@@ -112,7 +115,11 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     };
 
     // we're loading the entire file into memory, we need to check avail mem
-    util::mem_file_check(&std::path::PathBuf::from(&input_path))?;
+    util::mem_file_check(
+        &std::path::PathBuf::from(&input_path),
+        false,
+        args.flag_no_memcheck,
+    )?;
 
     // we can do this directly here, since args is mutable and
     // Config has not been created yet at this point
@@ -338,7 +345,7 @@ pub fn infer_schema_from_stats(args: &Args, input_filename: &str) -> CliResult<M
                 }
             }
             _ => {
-                warn!("Stats gave unexpected field type '{col_type}', default to JSON String.");
+                wwarn!("Stats gave unexpected field type '{col_type}', default to JSON String.");
                 // defaults to JSON String
                 type_list.push(Value::String("string".to_string()));
             }
@@ -393,6 +400,7 @@ fn get_stats_records(args: &Args) -> CliResult<(ByteRecord, Vec<Stats>, AHashMap
         flag_output:          None,
         flag_no_headers:      args.flag_no_headers,
         flag_delimiter:       args.flag_delimiter,
+        flag_no_memcheck:     args.flag_no_memcheck,
     };
 
     let (csv_fields, csv_stats) = match stats_args.rconfig().indexed() {
@@ -406,7 +414,7 @@ fn get_stats_records(args: &Args) -> CliResult<(ByteRecord, Vec<Stats>, AHashMap
             }
         }
         Err(e) => {
-            warn!("error determining if indexed, triggering sequential stats: {e}");
+            wwarn!("error determining if indexed, triggering sequential stats: {e}");
             stats_args.sequential_stats(&stats_args.flag_dates_whitelist)
         }
     }?;
@@ -472,15 +480,16 @@ fn get_unique_values(
 ) -> CliResult<AHashMap<String, Vec<String>>> {
     // prepare arg for invoking cmd::frequency
     let freq_args = crate::cmd::frequency::Args {
-        arg_input:       args.arg_input.clone(),
-        flag_select:     crate::select::SelectColumns::parse(column_select_arg).unwrap(),
-        flag_limit:      args.flag_enum_threshold,
-        flag_asc:        false,
-        flag_no_nulls:   true,
-        flag_jobs:       Some(util::njobs(args.flag_jobs)),
-        flag_output:     None,
-        flag_no_headers: args.flag_no_headers,
-        flag_delimiter:  args.flag_delimiter,
+        arg_input:        args.arg_input.clone(),
+        flag_select:      crate::select::SelectColumns::parse(column_select_arg).unwrap(),
+        flag_limit:       args.flag_enum_threshold,
+        flag_asc:         false,
+        flag_no_nulls:    true,
+        flag_jobs:        Some(util::njobs(args.flag_jobs)),
+        flag_output:      None,
+        flag_no_headers:  args.flag_no_headers,
+        flag_delimiter:   args.flag_delimiter,
+        flag_no_memcheck: args.flag_no_memcheck,
     };
 
     let (headers, ftables) = match freq_args.rconfig().indexed()? {
