@@ -125,10 +125,22 @@ pub fn version() -> String {
     enabled_features.push_str("self_update");
     enabled_features.push('-');
 
+    // get max_file_size & memory info. max_file_size is based on QSV_FREEMEMORY_HEADROOM_PCT
+    // setting and is only enforced when qsv is running in "non-streaming" mode (i.e. needs to
+    // load the entire file into memory).
+    let max_file_size = mem_file_check(Path::new(""), true, false).unwrap_or(0) as u64;
+    let mut sys = System::new();
+    sys.refresh_memory();
+    let avail_mem = sys.available_memory();
+    let total_mem = sys.total_memory();
+    let free_swap = sys.free_swap();
+
     #[cfg(feature = "mimalloc")]
-    let malloc_kind = "mimalloc".to_string();
-    #[cfg(not(feature = "mimalloc"))]
-    let malloc_kind = "standard".to_string();
+    let malloc_kind = "mimalloc";
+    #[cfg(feature = "jemallocator")]
+    let malloc_kind = "jemalloc";
+    #[cfg(not(any(feature = "mimalloc", feature = "jemallocator")))]
+    let malloc_kind = "standard";
     let (qsvtype, maj, min, pat, pre, rustversion) = (
         option_env!("CARGO_BIN_NAME"),
         option_env!("CARGO_PKG_VERSION_MAJOR"),
@@ -137,27 +149,37 @@ pub fn version() -> String {
         option_env!("CARGO_PKG_VERSION_PRE"),
         option_env!("CARGO_PKG_RUST_VERSION"),
     );
-    match (qsvtype, maj, min, pat, pre, rustversion) {
-        (Some(qsvtype), Some(maj), Some(min), Some(pat), Some(pre), Some(rustversion)) => {
-            if pre.is_empty() {
-                format!(
-                    "{qsvtype} {maj}.{min}.\
-                     {pat}-{malloc_kind}-{enabled_features}{maxjobs}-{numcpus} ({TARGET} compiled \
-                     with Rust {rustversion}) {QSV_KIND}",
-                    maxjobs = max_jobs(),
-                    numcpus = num_cpus()
-                )
-            } else {
-                format!(
-                    "{qsvtype} {maj}.{min}.\
-                     {pat}-{pre}-{malloc_kind}-{enabled_features}{maxjobs}-{numcpus} ({TARGET} \
-                     compiled with Rust {rustversion}) {QSV_KIND}",
-                    maxjobs = max_jobs(),
-                    numcpus = num_cpus(),
-                )
-            }
+    if let (Some(qsvtype), Some(maj), Some(min), Some(pat), Some(pre), Some(rustversion)) =
+        (qsvtype, maj, min, pat, pre, rustversion)
+    {
+        if pre.is_empty() {
+            format!(
+                "{qsvtype} {maj}.{min}.{pat}-{malloc_kind}-{enabled_features}{maxjobs}-{numcpus};\
+                 {max_file_size}-{free_swap}-{avail_mem}-{total_mem} ({TARGET} compiled with Rust \
+                 {rustversion}) {QSV_KIND}",
+                maxjobs = max_jobs(),
+                numcpus = num_cpus(),
+                max_file_size = indicatif::HumanBytes(max_file_size),
+                free_swap = indicatif::HumanBytes(free_swap),
+                avail_mem = indicatif::HumanBytes(avail_mem),
+                total_mem = indicatif::HumanBytes(total_mem),
+            )
+        } else {
+            format!(
+                "{qsvtype} {maj}.{min}.\
+                 {pat}-{pre}-{malloc_kind}-{enabled_features}{maxjobs}-{numcpus};\
+                 {max_file_size}-{free_swap}-{avail_mem}-{total_mem} ({TARGET} compiled with Rust \
+                 {rustversion}) {QSV_KIND}",
+                maxjobs = max_jobs(),
+                numcpus = num_cpus(),
+                max_file_size = indicatif::HumanBytes(max_file_size),
+                free_swap = indicatif::HumanBytes(free_swap),
+                avail_mem = indicatif::HumanBytes(avail_mem),
+                total_mem = indicatif::HumanBytes(total_mem),
+            )
         }
-        _ => String::new(),
+    } else {
+        String::new()
     }
 }
 
@@ -187,7 +209,9 @@ pub fn count_rows(conf: &Config) -> Result<u64, CliError> {
     } else {
         // index does not exist or is stale,
         // count records by iterating through records
-        // however, do this only once per invocation and cache the result
+        // Do this only once per invocation and cache the result, so we don't
+        // have to re-count rows every time we need to know the row count for CSVs
+        // that don't have an index.
         let rc = ROW_COUNT.get_or_init(|| {
             if let Ok(mut rdr) = conf.reader() {
                 let mut count = 0u64;
@@ -197,6 +221,7 @@ pub fn count_rows(conf: &Config) -> Result<u64, CliError> {
                 }
                 count
             } else {
+                // sentinel value to indicate that we were unable to count rows
                 u64::MAX
             }
         });
@@ -306,7 +331,6 @@ pub fn many_configs(
             Config::new(&Some(p))
                 .delimiter(delim)
                 .no_headers(no_headers)
-                .checkutf8(false)
         })
         .collect::<Vec<_>>();
     errif_greater_one_stdin(&confs)?;
@@ -347,22 +371,22 @@ pub fn file_metadata(md: &fs::Metadata) -> (u64, u64) {
     (last_modified, fsize)
 }
 
-pub fn mem_file_check(path: &Path) -> Result<(), String> {
-    use indicatif::HumanBytes;
-
-    // if the file doesn't exist, we don't need to check memory
-    // as file existence is checked before this function is called
-    // and if we do get here with a non-existent file, that means
-    // we're using stdin, so this check doesn't apply
-    if !path.exists() {
-        return Ok(());
+pub fn mem_file_check(path: &Path, version_check: bool, no_memcheck: bool) -> Result<i64, String> {
+    // if we're NOT calling this from the version() and the file doesn't exist,
+    // we don't need to check memory as file existence is checked before this function is called.
+    // If we do get here with a non-existent file, that means we're using stdin,
+    // so this check doesn't apply, so we return -1
+    if !path.exists() && !version_check {
+        return Ok(-1_i64);
     }
 
-    let avail_mem = {
-        let mut sys = System::new_all();
-        sys.refresh_memory();
-        sys.available_memory()
-    };
+    let no_memcheck_work = env::var("QSV_NO_MEMORY_CHECK").is_ok() || no_memcheck;
+
+    let mut sys = System::new();
+    sys.refresh_memory();
+    let total_mem = sys.total_memory();
+    let avail_mem = sys.available_memory();
+    let free_swap = sys.free_swap();
     let mut mem_pct = env::var("QSV_FREEMEMORY_HEADROOM_PCT")
         .unwrap_or_else(|_| DEFAULT_FREEMEMORY_HEADROOM_PCT.to_string())
         .parse::<u8>()
@@ -373,26 +397,37 @@ pub fn mem_file_check(path: &Path) -> Result<(), String> {
     mem_pct = mem_pct.clamp(10, 90);
 
     #[allow(clippy::cast_precision_loss)]
-    let max_avail_mem = (avail_mem as f32 * ((100 - mem_pct) as f32 / 100.0_f32)) as u64;
+    let max_avail_mem = if no_memcheck_work {
+        (total_mem as f32 * ((100 - mem_pct) as f32 / 100.0_f32)) as u64
+    } else {
+        ((avail_mem + free_swap) as f32 * ((100 - mem_pct) as f32 / 100.0_f32)) as u64
+    };
 
-    let file_metadata = fs::metadata(path).map_err(|e| format!("Failed to get file size: {e}"))?;
-    let fsize = file_metadata.len();
-    let detail_msg = format!(
-        "qsv running in non-streaming mode. Available memory: {avail_mem}. Max Available memory: \
-         {max_avail_mem}. QSV_FREEMEMORY_HEADROOM_PCT: {mem_pct} percent. File size: {fsize}.",
-        avail_mem = HumanBytes(avail_mem),
-        max_avail_mem = HumanBytes(max_avail_mem),
-        mem_pct = mem_pct,
-        fsize = HumanBytes(fsize)
-    );
-    if fsize > max_avail_mem {
-        return fail!(format!(
-            "Not enough memory to process the file. {detail_msg}"
-        ));
+    // if we're calling this from version(), we don't need to check the file size
+    if !version_check {
+        let file_metadata =
+            fs::metadata(path).map_err(|e| format!("Failed to get file size: {e}"))?;
+        let fsize = file_metadata.len();
+        let detail_msg = format!(
+            "qsv running in non-streaming mode. Total memory: {total_mem} Available memory: \
+             {avail_mem}. Free swap: {free_swap} Max Available memory/Max input file size: \
+             {max_avail_mem}. QSV_FREEMEMORY_HEADROOM_PCT: {mem_pct}%. File size: {fsize}.",
+            total_mem = indicatif::HumanBytes(total_mem),
+            avail_mem = indicatif::HumanBytes(avail_mem),
+            free_swap = indicatif::HumanBytes(free_swap),
+            max_avail_mem = indicatif::HumanBytes(max_avail_mem),
+            mem_pct = mem_pct,
+            fsize = indicatif::HumanBytes(fsize)
+        );
+        log::info!("{detail_msg}");
+        if fsize > max_avail_mem {
+            return fail!(format!(
+                "Not enough memory to process the file. {detail_msg}"
+            ));
+        }
     }
-    log::info!("{detail_msg}");
 
-    Ok(())
+    Ok(max_avail_mem as i64)
 }
 
 #[cfg(any(feature = "full", feature = "lite"))]
